stravalib.util.limiter.LimitsStructure
======================================

.. currentmodule:: stravalib.util.limiter

.. autoclass:: LimitsStructure


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~LimitsStructure.__init__
      ~LimitsStructure.clear
      ~LimitsStructure.copy
      ~LimitsStructure.fromkeys
      ~LimitsStructure.get
      ~LimitsStructure.items
      ~LimitsStructure.keys
      ~LimitsStructure.pop
      ~LimitsStructure.popitem
      ~LimitsStructure.setdefault
      ~LimitsStructure.update
      ~LimitsStructure.values





   .. rubric:: Attributes

   .. autosummary::

      ~LimitsStructure.short
      ~LimitsStructure.long
